Mozzarilla is a file editing program, and is intended to be a complete replacement for Halo Custom Edition's Guerilla, with additional tools and ease of use upgrades. This is a screenshot of it with some of its extra tools shown.
![mozzarilla_0_9_3_by_chief_01-dasy581.png](https://bitbucket.org/repo/75eEL8/images/1306443699-mozzarilla_0_9_3_by_chief_01-dasy581.png)
![binilla test2.PNG](https://bitbucket.org/repo/4xyAzp/images/2229544774-binilla%20test2.PNG)

Here is a current list of the most prominent features of mozz:

*     Is able to switch between creating regular tags, open sauce tags, and gametypes.

*     Is able to view/edit hidden data(edit the config to enable it)

*     Is able to load corrupt tags for debugging purposes.

*     Can export/import blocks(pieces of a tag)

*     Makes backups of tags before editing.

*     Highly customizable user interface colors, widget sizes, hotkeys, etc.

*     Contains a customizable undo/redo feature.

*     Contains a hierarchy view for easily browsing a tags directory and loading tags.

*     Allows choosing any number of tags directories and switching between them at will.



Mozzarilla also contains a few special tools for aiding in modding:


*     Broken dependency scanner: For locating broken dependencies in the specified types of tags in the specified folder.

*     Dependency viewer: For easily seeing which tags a tag refers to and opening any of them.

*     Tag zipper: For making a zip folder containing a tag and every tag it depends on.



## Who do I talk to?



* Devin Bobadilla (Original author of mozzarilla) MoeMakesStuff@gmail.com
